==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/BaZdbhqkLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 宗地变化情况
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_zdbhqk_ls"
)
public class BaZdbhqkLs implements Serializable{

    @XmlAttribute
    private String zddm;

    @XmlAttribute
    private String bhyy;

    @XmlAttribute
    private String bhnr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    @id
    @Id
    private String id;

    @Nullable
    private Date sjgxsj;


    @bwmc
    private String bwmc;

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getZddm() {
        return zddm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    public String getBhyy() {
        return bhyy;
    }

    public void setBhyy(String bhyy) {
        this.bhyy = bhyy;
    }

    public String getBhnr() {
        return bhnr;
    }

    public void setBhnr(String bhnr) {
        this.bhnr = bhnr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }
}

==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaZdbhqkLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 宗地变化情况
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_zdbhqk_ls"
)
public class BaZdbhqkLs implements Serializable{

    @XmlAttribute
    private String zddm;

    @XmlAttribute
    private String bhyy;

    @XmlAttribute
    private String bhnr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    @id
    @Id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String bhqzddm;

    @XmlAttribute
    private String ssywh;

    public String getBhqzddm() {
        return bhqzddm;
    }

    public void setBhqzddm(String bhqzddm) {
        this.bhqzddm = bhqzddm;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getZddm() {
        return zddm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    public String getBhyy() {
        return bhyy;
    }

    public void setBhyy(String bhyy) {
        this.bhyy = bhyy;
    }

    public String getBhnr() {
        return bhnr;
    }

    public void setBhnr(String bhnr) {
        this.bhnr = bhnr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }
}
